@@ -1,14 +1,15 @@
-from .parse_xml import parse as parse_xml
-from shapely.ops import cascaded_union, linemerge
-from shapely.geometry import (
-    mapping, Polygon, Point, LineString, MultiLineString, MultiPolygon, GeometryCollection
-)
-from shapely.geometry.polygon import orient
+import json
+import logging
+import os
 import traceback
 from pprint import pformat
-import logging
-import json
-import os
+
+from shapely.geometry import (GeometryCollection, LineString, MultiLineString,
+                              MultiPolygon, Point, Polygon, mapping)
+from shapely.geometry.polygon import orient
+from shapely.ops import cascaded_union, linemerge
+
+from .parse_xml import parse as parse_xml
 
 logger = logging.getLogger(__name__)
 dirname = os.path.dirname(__file__)
@@ -68,10 +69,12 @@ def _json2shapes(data, filter_used_refs=True, log_level='ERROR'):
     logger.setLevel(log_level)
     shapes = []
 
-    refs = []
-    for el in data['elements']:
-        if el['type'] in ['node', 'way', 'relation']:
-            refs.append(el)
+    refs = [
+        el
+        for el in data['elements']
+        if el['type'] in ['node', 'way', 'relation']
+    ]
+
     refs_index = build_refs_index(refs)
 
     for el in data['elements']:
@@ -84,11 +87,10 @@ def _json2shapes(data, filter_used_refs=True, log_level='ERROR'):
     if not filter_used_refs:
         return shapes
 
-    used = {}
-    for ref in refs:
-        if 'used' in ref:
-            used[ref['id']] = ref['used']
-
+    used = {
+        ref['id']: ref['used']
+        for ref in refs if 'used' in ref
+    }
     filtered_shapes = []
     for shape in shapes:
         if 'properties' not in shape:
@@ -100,7 +102,7 @@ def _json2shapes(data, filter_used_refs=True, log_level='ERROR'):
     return filtered_shapes
 
 
-def element_to_shape(el, refs_index = None):
+def element_to_shape(el, refs_index=None):
     t = el['type']
     if t == 'node':
         return node_to_shape(el)
@@ -137,10 +139,10 @@ def get_node_ref(id, refs_index):
 
 
 def build_refs_index(elements):
-    obj = {}
-    for el in elements:
-        obj[get_ref_name(el)] = el
-    return obj
+    return {
+        get_ref_name(el): el
+        for el in elements
+    }
 
 
 def node_to_shape(node):
@@ -150,35 +152,42 @@ def node_to_shape(node):
     }
 
 
-def get_element_props(el, keys = ['type', 'id', 'tags']):
-    props = {}
-    for key in keys:
-        if key in el:
-            props[key] = el[key]
-    return props
+def get_element_props(el, keys=[
+    'type',
+    'id',
+    'tags',
+    'nodes',
+    'timestamp',
+    'user',
+    'uid',
+    'version'
+]
+):
+    return {
+        key: el[key]
+        for key in keys
+        if key in el
+    }
 
 
 def convert_coords_to_lists(coords):
-    new_coords = list()
     if len(coords) < 1:
-        return new_coords
+        return []
 
     if isinstance(coords[0], float):
         return list(coords)
 
-    for c in coords:
-        new_coords.append(convert_coords_to_lists(c))
-    return new_coords
+    return [convert_coords_to_lists(c) for c in coords]
 
 
-def shape_to_feature(g, props = {}):
+def shape_to_feature(g, props={}):
     # shapely returns tuples (we need lists)
-    g =  mapping(g)
+    g = mapping(g)
     g['coordinates'] = convert_coords_to_lists(g['coordinates'])
     return {
         "type": "Feature",
         'properties': props,
-        "geometry":g
+        "geometry": g
     }
 
 
@@ -196,9 +205,7 @@ def fix_invalid_polygon(p):
     return p
 
 
-def way_to_shape(way, refs_index = {}):
-    coords = []
-
+def way_to_shape(way, refs_index={}):
     if 'center' in way:
         center = way['center']
         return {
@@ -207,10 +214,13 @@ def way_to_shape(way, refs_index = {}):
         }
 
     if 'geometry' in way and len(way['geometry']) > 0:
-        for nd in way['geometry']:
-            coords.append([nd['lon'], nd['lat']])
+        coords = [
+            [nd['lon'], nd['lat']]
+            for nd in way['geometry']
+        ]
 
     elif 'nodes' in way and len(way['nodes']) > 0:
+        coords = []
         for ref in way['nodes']:
             node = get_node_ref(ref, refs_index)
             if node:
@@ -237,10 +247,11 @@ def way_to_shape(way, refs_index = {}):
         if ref_way is None:
             warning('Way by ref not converted to shape', pformat(way))
             return None
-        if isinstance(ref_way['shape'], Polygon):
-            coords = ref_way['shape'].exterior.coords
-        else:
-            coords = ref_way['shape'].coords
+        coords = (
+            ref_way['shape'].exterior
+            if isinstance(ref_way['shape'], Polygon)
+            else ref_way['shape']
+        ).coords
 
     else:
         # throw exception
@@ -259,7 +270,7 @@ def way_to_shape(way, refs_index = {}):
                 'shape': poly,
                 'properties': props
             }
-        except:
+        except Exception:
             warning('Failed to generate polygon from way', pformat(way))
             return None
     else:
@@ -310,6 +321,7 @@ def is_geometry_polygon(node):
     else:
         return False
 
+
 def is_geometry_polygon_without_exceptions(node):
     tags = node['tags']
     for rule in polygon_features:
@@ -319,10 +331,7 @@ def is_geometry_polygon_without_exceptions(node):
             if rule['polygon'] == 'whitelist' and tags[rule['key']] in rule['values']:
                 return True
             if rule['polygon'] == 'blacklist':
-                if tags[rule['key']] in rule['values']:
-                    return False
-                else:
-                    return True
+                return tags[rule['key']] not in rule['values']
     return False
 
 
@@ -339,7 +348,7 @@ def relation_to_shape(rel, refs_index):
             return multipolygon_relation_to_shape(rel, refs_index)
         else:
             return multiline_realation_to_shape(rel, refs_index)
-    except Exception as e:
+    except Exception:
         # traceback.print_exc()
         error('Failed to convert relation to shape', pformat(rel))
 
@@ -431,7 +440,7 @@ def multipolygon_relation_to_shape(rel, refs_index):
 
     multipolygon = fix_invalid_polygon(multipolygon)
     multipolygon = to_multipolygon(multipolygon)
-    multipolygon = orient_multipolygon(multipolygon) # do we need this?
+    multipolygon = orient_multipolygon(multipolygon)  # do we need this?
 
     return {
         'shape': multipolygon,
@@ -444,10 +453,10 @@ def to_multipolygon(obj):
         return obj
 
     if isinstance(obj, GeometryCollection):
-        p = []
-        for el in obj:
-            if isinstance(el, Polygon):
-                p.append(el)
+        p = [
+            el for el in obj
+            if isinstance(el, Polygon)
+        ]
         return MultiPolygon(p)
 
     if isinstance(obj, Polygon):
@@ -470,7 +479,7 @@ def _convert_lines_to_multipolygon(lines):
                     polygons.append(poly)
                 else:
                     polygons.append(poly.buffer(0))
-            except:
+            except Exception:
                 # throw exception
                 warning('Failed to build polygon', pformat(line))
         return to_multipolygon(cascaded_union(polygons))
@@ -483,7 +492,7 @@ def _convert_lines_to_multipolygon(lines):
     return to_multipolygon(poly)
 
 
-def convert_ways_to_multipolygon(outer, inner = []):
+def convert_ways_to_multipolygon(outer, inner=[]):
     if len(outer) < 1:
         # throw exception
         warning('Ways not found')
